#Supplemental data for PeerJ
rm(list=ls(all=TRUE))

library(dplyr)

library(readxl) #if excel files

Data    <- read_excel("Fish_length_data.xlsx")
Station <- read_excel("Trawl_operation_data.xlsx")

Euplaice <- subset(Data, Species == 23)#The species name of European plaice is noted as number "23" in the Trawl operation data

#combine the length data and Cod data in a data called Cod1 below

Euplaice1 <- merge(Euplaice, Station, by = 'Sampl_ID')

#remove some tows as they sampled inconsistencies
Euplaice1<-subset(Euplaice1, ST != 556 & ST != 561 & ST != 566&ST != 556 & ST != 561 & ST != 566& ST != 567&ST != 564&ST != 565)

#selecting the colums that need for analyses
Euplaice1<-select(Euplaice1, length, number, ST, codend)

#plot length freq...checking if merge looks OK
plot(number~length, data=Euplaice1)#look Ok

#subset codend number 2 and 4 which are wing bags, and codend number 3 is bosom bags 
Codend2<-subset(Euplaice1, codend == 2)
Codend2<-select(Codend2, -codend)#remove the codend column as it is no longer needed
Codend4<-subset(Euplaice1, codend == 4)
Codend4<-select(Codend4, -codend)#remove the codend column as it is no longer needed
Codend3<-subset(Euplaice1, codend == 3)
Codend3<-select(Codend3, -codend)#remove the codend column as it is no longer needed

#Join data of codend 2 and 4 for the catch of wing bags
DataNew1 <- full_join(Codend2, Codend4, by = c("ST", "length"))
#Join data of codend 2 and 4 and 3 for the analysis
DataNew2<-full_join(DataNew1, Codend3, by = c("ST", "length"))
DataNew2[is.na(DataNew2)] <- 0#remove NA in the dataset

#change the name of colums
names(DataNew2)<- c("length", "Codend2","ST",  "Codend4", "Codend3" ) 

#suming catch of wing bags
DataNew2$twofour<-DataNew2$Codend2+DataNew2$Codend4

Data<-DataNew2[,c(1,3,5,6)]#Drop column 2 and 4 as they are no longer needed

#Change the name of columns
names(Data)<- c("MLL", "Tow","Bosom",  "Wing")

#save data frame
write.table(Data,  file = "Suplemental_European_plaice_data.txt", sep ="\t" ,row.names = TRUE, col.names = TRUE)
